==> aroundme_0_6_7.zip: aroundme_0_6_7/aroundme/config/config_acs.inc.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003, 2004 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------
// Tom Calthrop - 14th September 2005 (info@barnraiser.org)



// RESOURCES --------------------------------------------------------------------
// A list of resources available within the build
$c_acs['arr_acs']['resource']['node']['administration'] = 	"1";
$c_acs['arr_acs']['resource']['node']['network'] = 			"2";
$c_acs['arr_acs']['resource']['node']['rsp'] = 				"3";
$c_acs['arr_acs']['resource']['node']['shoutbox'] = 		"4";
$c_acs['arr_acs']['resource']['node']['library'] = 			"5";
$c_acs['arr_acs']['resource']['node']['forum'] = 			"6";
$c_acs['arr_acs']['resource']['node']['files'] = 			"7";
$c_acs['arr_acs']['resource']['node']['schedule'] = 		"8";
$c_acs['arr_acs']['resource']['node']['poll'] = 			"9";
$c_acs['arr_acs']['resource']['node']['blog'] = 			"10";
$c_acs['arr_acs']['resource']['node']['channels'] = 		"11";
$c_acs['arr_acs']['resource']['node']['group'] = 			"12";
$c_acs['arr_acs']['resource']['node']['tagging'] = 			"13";
$c_acs['arr_acs']['resource']['node']['skills'] = 			"14";

$c_acs['arr_acs']['resource']['group']['administration'] = 		"201";
$c_acs['arr_acs']['resource']['group']['library'] = 			"202";
$c_acs['arr_acs']['resource']['group']['forum'] = 				"203";
$c_acs['arr_acs']['resource']['group']['files'] = 				"204";
$c_acs['arr_acs']['resource']['group']['schedule'] = 			"205";
$c_acs['arr_acs']['resource']['group']['poll'] = 				"206";
$c_acs['arr_acs']['resource']['group']['blog'] = 				"207";
$c_acs['arr_acs']['resource']['group']['channels'] = 			"208";
$c_acs['arr_acs']['resource']['group']['rsp'] = 				"209";



// RESOURCE PRIVILEGE CONFIGURATION
// privileges are attached to resources
// $c_acs['resource_privilege'][1] - '1' refers to the id of the language
// array ( $acs['arr_resource'][1])
// we store an array of privilege_id's which refer to the id of the privilege
// array ( $acs['arr_privilege'][1])
//
$c_acs['resource_privilege'][1] = 			array(1,2,3,5,26); 			//administration
$c_acs['resource_privilege'][2] = 			array(6,7,8,9,18,19); 		//network
$c_acs['resource_privilege'][3] = 			array(15,16,17,23,27,28); 		//rsp
$c_acs['resource_privilege'][4] = 			array(10,11); 				//shoutbox
$c_acs['resource_privilege'][5] = 			array(10,11,12,18,25); 		//library
$c_acs['resource_privilege'][6] = 			array(10,11,12,13,14,18,23); //forum
$c_acs['resource_privilege'][7] = 			array(10,11); 				//files
$c_acs['resource_privilege'][8] = 			array(10,11,12,18); 		//schedule
$c_acs['resource_privilege'][9] = 			array(10,11,12,18); 		//poll
$c_acs['resource_privilege'][10] = 			array(10,11,12,18); 		//blog
$c_acs['resource_privilege'][11] = 			array(10,11); 				//channel
$c_acs['resource_privilege'][12] = 			array(18,20); 					//group
$c_acs['resource_privilege'][13] = 			array(10,24); 				//tagging
$c_acs['resource_privilege'][14] = 			array(10); 					//skills

$c_acs['resource_privilege'][201] = 		array(1,2,3,5,21,22,23); 	//administration
$c_acs['resource_privilege'][202] = 		array(10,11,12,18,25); 		//library
$c_acs['resource_privilege'][203] = 		array(10,11,12,13,14,18,23); //forum
$c_acs['resource_privilege'][204] = 		array(10,11); 				//files
$c_acs['resource_privilege'][205] = 		array(10,11,12,18); 		//schedule
$c_acs['resource_privilege'][206] = 		array(10,11,12,18); 		//poll
$c_acs['resource_privilege'][207] = 		array(10,11,12,18); 		//blog
$c_acs['resource_privilege'][208] = 		array(10,11); 				//channel
$c_acs['resource_privilege'][209] = 		array(4,16,17,23); 			//rsp

// PRIVILEGES --------------------------------------------------------------------
// A list of privileges available within the build
$c_acs['arr_acs']['privilege']['allow_membership'] = 		"1";
$c_acs['arr_acs']['privilege']['allow_newsletter'] = 		"2";
$c_acs['arr_acs']['privilege']['allow_acs'] = 				"3";
$c_acs['arr_acs']['privilege']['allow_rsp_group_home'] = 	"4";
$c_acs['arr_acs']['privilege']['allow_abuse_reports'] = 	"5";
$c_acs['arr_acs']['privilege']['allow_directory'] = 		"6";
$c_acs['arr_acs']['privilege']['allow_network'] = 			"7";
$c_acs['arr_acs']['privilege']['allow_network_int'] = 		"8";
$c_acs['arr_acs']['privilege']['allow_network_ext'] = 		"9";
$c_acs['arr_acs']['privilege']['allow_access'] = 			"10";
$c_acs['arr_acs']['privilege']['add_item'] = 				"11";
$c_acs['arr_acs']['privilege']['allow_comment'] =	 		"12";
$c_acs['arr_acs']['privilege']['allow_locking'] = 			"13";
$c_acs['arr_acs']['privilege']['allow_hidden'] = 			"14";
$c_acs['arr_acs']['privilege']['allow_rsp_network'] = 		"15";
$c_acs['arr_acs']['privilege']['allow_rsp_node'] = 			"16";
$c_acs['arr_acs']['privilege']['allow_rsp_public'] = 		"17";
$c_acs['arr_acs']['privilege']['allow_tagging'] = 			"18";
$c_acs['arr_acs']['privilege']['allow_profile'] = 			"19";
$c_acs['arr_acs']['privilege']['allow_create'] = 			"20";
$c_acs['arr_acs']['privilege']['edit_membership'] = 		"21";
$c_acs['arr_acs']['privilege']['allow_tag'] = 				"22";
$c_acs['arr_acs']['privilege']['allow_edit'] = 				"23";
$c_acs['arr_acs']['privilege']['allow_sch_tag_mgmt'] = 		"24";
$c_acs['arr_acs']['privilege']['allow_lib_default'] = 		"25";
$c_acs['arr_acs']['privilege']['allow_group_mgmt'] = 		"26";
$c_acs['arr_acs']['privilege']['allow_rsp_node_featured'] = "27";
$c_acs['arr_acs']['privilege']['allow_rsp_public_featured'] = "28";


// DEFAULTS --------------------------------------------------------------------
//what is the default role_id for a user at registration
$c_acs['arr_acs']['user_join_role_default'] = 				"3";
//what is the default role_id for the group administrator (used at group create)
$c_acs['arr_acs']['group_administrator_role'] = 			"1";
// what is the default role for a member joining a group at group create time?
$c_acs['arr_acs']['group_join_role_default'] = 				"3";
// what is the default visitor role for use at group create time?
$c_acs['arr_acs']['group_join_role_visitor'] = 				"4";


// END OF CONFIGURATION FILE ---------------------------------------------

?>

==> aroundme_0_6_8.zip: aroundme_0_6_8/aroundme/config/config_acs.inc.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003, 2004 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------
// Tom Calthrop - 14th September 2005 (info@barnraiser.org)



// RESOURCES --------------------------------------------------------------------
// A list of resources available within the build
$c_acs['arr_acs']['resource']['node']['administration'] = 	"1";
$c_acs['arr_acs']['resource']['node']['network'] = 			"2";
$c_acs['arr_acs']['resource']['node']['rsp'] = 				"3";
$c_acs['arr_acs']['resource']['node']['shoutbox'] = 		"4";
$c_acs['arr_acs']['resource']['node']['library'] = 			"5";
$c_acs['arr_acs']['resource']['node']['forum'] = 			"6";
$c_acs['arr_acs']['resource']['node']['files'] = 			"7";
$c_acs['arr_acs']['resource']['node']['schedule'] = 		"8";
$c_acs['arr_acs']['resource']['node']['poll'] = 			"9";
$c_acs['arr_acs']['resource']['node']['blog'] = 			"10";
$c_acs['arr_acs']['resource']['node']['channels'] = 		"11";
$c_acs['arr_acs']['resource']['node']['group'] = 			"12";
$c_acs['arr_acs']['resource']['node']['tagging'] = 			"13";
$c_acs['arr_acs']['resource']['node']['skills'] = 			"14";
$c_acs['arr_acs']['resource']['node']['quiz'] = 			"15";

$c_acs['arr_acs']['resource']['group']['administration'] = 		"201";
$c_acs['arr_acs']['resource']['group']['library'] = 			"202";
$c_acs['arr_acs']['resource']['group']['forum'] = 				"203";
$c_acs['arr_acs']['resource']['group']['files'] = 				"204";
$c_acs['arr_acs']['resource']['group']['schedule'] = 			"205";
$c_acs['arr_acs']['resource']['group']['poll'] = 				"206";
$c_acs['arr_acs']['resource']['group']['blog'] = 				"207";
$c_acs['arr_acs']['resource']['group']['channels'] = 			"208";
$c_acs['arr_acs']['resource']['group']['rsp'] = 				"209";
$c_acs['arr_acs']['resource']['group']['quiz'] = 				"210";



// RESOURCE PRIVILEGE CONFIGURATION
// privileges are attached to resources
// $c_acs['resource_privilege'][1] - '1' refers to the id of the language
// array ( $acs['arr_resource'][1])
// we store an array of privilege_id's which refer to the id of the privilege
// array ( $acs['arr_privilege'][1])
//
$c_acs['resource_privilege'][1] = 			array(1,2,3,5,26); 			//administration
$c_acs['resource_privilege'][2] = 			array(6,7,8,9,18,19); 		//network
$c_acs['resource_privilege'][3] = 			array(15,16,17,23,27,28); 		//rsp
$c_acs['resource_privilege'][4] = 			array(10,11); 				//shoutbox
$c_acs['resource_privilege'][5] = 			array(10,11,12,18,25); 		//library
$c_acs['resource_privilege'][6] = 			array(10,11,12,13,14,18,23); //forum
$c_acs['resource_privilege'][7] = 			array(10,11); 				//files
$c_acs['resource_privilege'][8] = 			array(10,11,12,18); 		//schedule
$c_acs['resource_privilege'][9] = 			array(10,11,12,18); 		//poll
$c_acs['resource_privilege'][10] = 			array(10,11,12,18); 		//blog
$c_acs['resource_privilege'][11] = 			array(10,11); 				//channel
$c_acs['resource_privilege'][12] = 			array(18,20); 					//group
$c_acs['resource_privilege'][13] = 			array(10,24); 				//tagging
$c_acs['resource_privilege'][14] = 			array(10); 					//skills
$c_acs['resource_privilege'][15] = 			array(10,11,12,18); 		//quiz

$c_acs['resource_privilege'][201] = 		array(1,2,3,5,21,22,23); 	//administration
$c_acs['resource_privilege'][202] = 		array(10,11,12,18,25); 		//library
$c_acs['resource_privilege'][203] = 		array(10,11,12,13,14,18,23); //forum
$c_acs['resource_privilege'][204] = 		array(10,11); 				//files
$c_acs['resource_privilege'][205] = 		array(10,11,12,18); 		//schedule
$c_acs['resource_privilege'][206] = 		array(10,11,12,18); 		//poll
$c_acs['resource_privilege'][207] = 		array(10,11,12,18); 		//blog
$c_acs['resource_privilege'][208] = 		array(10,11); 				//channel
$c_acs['resource_privilege'][209] = 		array(4,16,17,23); 			//rsp
$c_acs['resource_privilege'][210] = 		array(10,11,12,18); 		//quiz

// PRIVILEGES --------------------------------------------------------------------
// A list of privileges available within the build
$c_acs['arr_acs']['privilege']['allow_membership'] = 		"1";
$c_acs['arr_acs']['privilege']['allow_newsletter'] = 		"2";
$c_acs['arr_acs']['privilege']['allow_acs'] = 				"3";
$c_acs['arr_acs']['privilege']['allow_rsp_group_home'] = 	"4";
$c_acs['arr_acs']['privilege']['allow_abuse_reports'] = 	"5";
$c_acs['arr_acs']['privilege']['allow_directory'] = 		"6";
$c_acs['arr_acs']['privilege']['allow_network'] = 			"7";
$c_acs['arr_acs']['privilege']['allow_network_int'] = 		"8";
$c_acs['arr_acs']['privilege']['allow_network_ext'] = 		"9";
$c_acs['arr_acs']['privilege']['allow_access'] = 			"10";
$c_acs['arr_acs']['privilege']['add_item'] = 				"11";
$c_acs['arr_acs']['privilege']['allow_comment'] =	 		"12";
$c_acs['arr_acs']['privilege']['allow_locking'] = 			"13";
$c_acs['arr_acs']['privilege']['allow_hidden'] = 			"14";
$c_acs['arr_acs']['privilege']['allow_rsp_network'] = 		"15";
$c_acs['arr_acs']['privilege']['allow_rsp_node'] = 			"16";
$c_acs['arr_acs']['privilege']['allow_rsp_public'] = 		"17";
$c_acs['arr_acs']['privilege']['allow_tagging'] = 			"18";
$c_acs['arr_acs']['privilege']['allow_profile'] = 			"19";
$c_acs['arr_acs']['privilege']['allow_create'] = 			"20";
$c_acs['arr_acs']['privilege']['edit_membership'] = 		"21";
$c_acs['arr_acs']['privilege']['allow_tag'] = 				"22";
$c_acs['arr_acs']['privilege']['allow_edit'] = 				"23";
$c_acs['arr_acs']['privilege']['allow_sch_tag_mgmt'] = 		"24";
$c_acs['arr_acs']['privilege']['allow_lib_default'] = 		"25";
$c_acs['arr_acs']['privilege']['allow_group_mgmt'] = 		"26";
$c_acs['arr_acs']['privilege']['allow_rsp_node_featured'] = "27";
$c_acs['arr_acs']['privilege']['allow_rsp_public_featured'] = "28";


// DEFAULTS --------------------------------------------------------------------
//what is the default role_id for a user at registration
$c_acs['arr_acs']['user_join_role_default'] = 				"3";
//what is the default role_id for the group administrator (used at group create)
$c_acs['arr_acs']['group_administrator_role'] = 			"1";
// what is the default role for a member joining a group at group create time?
$c_acs['arr_acs']['group_join_role_default'] = 				"3";
// what is the default visitor role for use at group create time?
$c_acs['arr_acs']['group_join_role_visitor'] = 				"4";


// END OF CONFIGURATION FILE ---------------------------------------------

?>
